#!/bin/bash

# exit upon errors
set -e

# change the working directory to the one with the called script
cd "$(dirname "${0}")" # the escaping may look strange, but it works

# get sensible number for how many parallel jobs to use for make
NUM_PARALLEL_JOBS="$(($(nproc) + 1))"
if (( $? != 0 )); then
	NUM_PARALLEL_JOBS=1
fi

platform='unknown'
unamestr=`uname`
if [[ "$unamestr" == 'Linux' ]]; then
platform='linux'
elif [[ "$unamestr" == 'FreeBSD' ]]; then
platform='freebsd'
elif [[ "$unamestr" == 'Darwin' ]]; then
platform='darwin'  # MAC OS
fi


case $platform in
	linux)
		./autogen.sh
		./configure --enable-shared --disable-documentation --prefix=`pwd`/localInstDir --enable-examples --disable-tests
		make -j"$NUM_PARALLEL_JOBS"
		make install
		;;
	darwin)
		./autogen.sh
		./configure --enable-shared --disable-documentation --prefix=`pwd`/localInstDir --enable-examples --disable-tests
		make -j"$NUM_PARALLEL_JOBS"
		make install
		;;
	*)
		echo "WARNING:  compilation of coap_phoenix not yet supported for platform $platform"
		echo "WARNING:  skipping compilation and installation of coap_phoenix"
		;;
esac
